@@ -36,12 +36,16 @@ pub mod janus_auth;
 pub use self::janus_auth::JanusAuth;
 pub mod janus_auth_request;
 pub use self::janus_auth_request::JanusAuthRequest;
+pub mod janus_cloud_stream;
+pub use self::janus_cloud_stream::JanusCloudStream;
 pub mod janus_config_type;
 pub use self::janus_config_type::JanusConfigType;
+pub mod janus_edge_stream;
+pub use self::janus_edge_stream::JanusEdgeStream;
+pub mod janus_edge_stream_request;
+pub use self::janus_edge_stream_request::JanusEdgeStreamRequest;
 pub mod janus_stream;
 pub use self::janus_stream::JanusStream;
-pub mod janus_stream_request;
-pub use self::janus_stream_request::JanusStreamRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod octo_print_backup;
@@ -64,8 +68,10 @@ pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
 pub mod paginated_janus_auth_list;
 pub use self::paginated_janus_auth_list::PaginatedJanusAuthList;
-pub mod paginated_janus_stream_list;
-pub use self::paginated_janus_stream_list::PaginatedJanusStreamList;
+pub mod paginated_janus_cloud_stream_list;
+pub use self::paginated_janus_cloud_stream_list::PaginatedJanusCloudStreamList;
+pub mod paginated_janus_edge_stream_list;
+pub use self::paginated_janus_edge_stream_list::PaginatedJanusEdgeStreamList;
 pub mod paginated_octo_print_backup_list;
 pub use self::paginated_octo_print_backup_list::PaginatedOctoPrintBackupList;
 pub mod paginated_octo_print_settings_list;
@@ -90,8 +96,8 @@ pub mod patched_cloudiot_device_request;
 pub use self::patched_cloudiot_device_request::PatchedCloudiotDeviceRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
-pub mod patched_janus_stream_request;
-pub use self::patched_janus_stream_request::PatchedJanusStreamRequest;
+pub mod patched_janus_edge_stream_request;
+pub use self::patched_janus_edge_stream_request::PatchedJanusEdgeStreamRequest;
 pub mod patched_octo_print_settings_request;
 pub use self::patched_octo_print_settings_request::PatchedOctoPrintSettingsRequest;
 pub mod patched_octo_printer_profile_request;
